#' gibble package
#'
#' Path-based geometry decomposition to data frame.
#' @name gibble-package
#' @docType package
NULL

#' minimal mesh
#'
#' A testing data set, composed of two MULTIPOLYGONs sharing one edge.
#' @name minimal_mesh
#' @docType data
NULL

#' hsh, home sweet home
#'
#' A testing data set, a list of poly, line, points
#' @name hsh
#' @docType data
NULL
